@@ -12,7 +12,7 @@
         <location filename="../aboutdialog/lxqtaboutdialog.cpp" line="96"/>
         <source>Advanced, easy-to-use, and fast desktop environment based on Qt technologies.</source>
         <comment>About dialog, &apos;About&apos; tab text</comment>
-        <translation>Ambiente de trabalho rápido, simples e fácil de utilizar baseado na tecnologia Qt.</translation>
+        <translation>Ambiente de trabalho rápido, simples e fácil de utilizar, baseado na tecnologia Qt.</translation>
     </message>
     <message>
         <location filename="../aboutdialog/lxqtaboutdialog.cpp" line="98"/>
@@ -22,9 +22,9 @@
     </message>
     <message>
         <location filename="../aboutdialog/lxqtaboutdialog.cpp" line="100"/>
-        <source>Copyright: %1-%2 %3</source>
+        <source>Copyright: © %1-%2 %3</source>
         <comment>About dialog, &apos;About&apos; tab text</comment>
-        <translation>Direitos de autor: %1-%2 %3</translation>
+        <translation>Copyright: © %1-%2 %3</translation>
     </message>
     <message>
         <location filename="../aboutdialog/lxqtaboutdialog.cpp" line="102"/>
@@ -42,102 +42,33 @@
         <location filename="../aboutdialog/lxqtaboutdialog.cpp" line="114"/>
         <source>LXQt is developed by the &lt;a %1&gt;LXQt Team and contributors&lt;/a&gt;.</source>
         <comment>About dialog, &apos;Authors&apos; tab text</comment>
-        <translation>O LxQt é desenvolvido pelos &lt;a %1&gt;colaboradores da equipa LxQt&lt;/a&gt;.</translation>
+        <translation>O LXQt é desenvolvido pela Equipe LXQt e os seus&lt;a %1&gt;contribuídores&lt;/a&gt;.</translation>
     </message>
     <message>
         <location filename="../aboutdialog/lxqtaboutdialog.cpp" line="116"/>
         <source>If you are interested in working with our development team, &lt;a %1&gt;join us&lt;/a&gt;.</source>
         <comment>About dialog, &apos;Authors&apos; tab text</comment>
-        <translation>Se quiser ajudar no desenvolvimento, &lt;a %1&gt;pode integrar a nossa equipa&lt;/a&gt;.</translation>
+        <translation>Se você estiver interessado em trabalhar com nossa equipe de desenvolvimento, &lt;a %1&gt;junte-se a nós&lt;/a&gt;.</translation>
     </message>
     <message>
-        <location filename="../aboutdialog/lxqtaboutdialog.cpp" line="134"/>
+        <location filename="../aboutdialog/lxqtaboutdialog.cpp" line="133"/>
         <source>Special thanks to:</source>
         <comment>About dialog, &apos;Thanks&apos; tab text</comment>
-        <translation>Um especial obrigado:</translation>
+        <translation>Agradecimentos especiais:</translation>
     </message>
     <message>
-        <location filename="../aboutdialog/lxqtaboutdialog.cpp" line="141"/>
+        <location filename="../aboutdialog/lxqtaboutdialog.cpp" line="140"/>
         <source>LXQt is translated into many languages thanks to the work of the translation teams all over the world.</source>
         <comment>About dialog, &apos;Translations&apos; tab text</comment>
-        <translation>O LxQt está traduzido em diversos idiomas graças ao trabalho desenvolvido pelas equipas de tradução de todo o mundo.</translation>
-    </message>
-    <message>
-        <source>Yes</source>
-        <translation type="obsolete">Sim</translation>
-    </message>
-    <message>
-        <source>No</source>
-        <translation type="obsolete">Não</translation>
-    </message>
-    <message>
-        <source>&lt;b&gt;LxQt Desktop Toolbox - Technical Info&lt;/b&gt;</source>
-        <translation type="obsolete">&lt;b&gt;Ambiente de trabalho LXQt - Informações técnicas&lt;/b&gt;</translation>
-    </message>
-    <message>
-        <source>Version</source>
-        <translation type="obsolete">Versão</translation>
-    </message>
-    <message>
-        <source>Qt</source>
-        <translation type="obsolete">Qt</translation>
-    </message>
-    <message>
-        <source>Debug Build</source>
-        <translation type="obsolete">Compilação de depuração</translation>
-    </message>
-    <message>
-        <source>System Configuration</source>
-        <translation type="obsolete">Configuração do sistema</translation>
-    </message>
-    <message>
-        <source>Share Directory</source>
-        <translation type="obsolete">Diretório de partilha</translation>
-    </message>
-    <message>
-        <source>Translations</source>
-        <comment>About dialog, Tab title</comment>
-        <translation type="obsolete">Traduções</translation>
-    </message>
-    <message>
-        <source>&lt;b&gt;User Directories&lt;/b&gt;</source>
-        <translation type="obsolete">Diretórios do utilizador</translation>
-    </message>
-    <message>
-        <source>Xdg Data Home</source>
-        <translation type="obsolete">Diretório dos dados do utilizador</translation>
-    </message>
-    <message>
-        <source>Xdg Config Home</source>
-        <translation type="obsolete">Diretório das configurações do utilizador</translation>
-    </message>
-    <message>
-        <source>Xdg Data Dirs</source>
-        <translation type="obsolete">Diretórios de dados</translation>
-    </message>
-    <message>
-        <source>Xdg Cache Home</source>
-        <translation type="obsolete">Diretório de cache do utilizador</translation>
-    </message>
-    <message>
-        <source>Xdg Runtime Home</source>
-        <translation type="obsolete">Diretório de execução do utilizador</translation>
-    </message>
-    <message>
-        <source>Xdg Autostart Dirs</source>
-        <translation type="obsolete">Diretórios de arranque automático</translation>
-    </message>
-    <message>
-        <source>Xdg Autostart Home</source>
-        <translation type="obsolete">Diretório de arranque automático do utilizador</translation>
+        <translation>O LXQt está traduzido em diversos idiomas graças ao trabalho desenvolvido pelas equipes de tradução de todo o mundo.</translation>
     </message>
 </context>
 <context>
     <name>about</name>
     <message>
         <location filename="../aboutdialog/lxqtaboutdialog.ui" line="14"/>
-        <source> About LXQt</source>
-        <translation> Sobre o LXQt</translation>
+        <source>About LXQt</source>
+        <translation>Acerca de LXQt</translation>
     </message>
     <message>
         <location filename="../aboutdialog/lxqtaboutdialog.ui" line="66"/>
@@ -172,7 +103,7 @@
     <message>
         <location filename="../aboutdialog/lxqtaboutdialog.ui" line="165"/>
         <source>Copy to clipboard</source>
-        <translation>Copiar para a área de transferência</translation>
+        <translation>Copiar para área de transferência</translation>
     </message>
 </context>
 </TS>
